Link budgets
============

Channel capacity
----------------

.. python-apigen-group:: link-budget-channel-capacity

Path losses
-----------

.. python-apigen-group:: link-budget-path-losses

Antennas
--------

.. python-apigen-group:: link-budget-antennas
